Index: forms.py
===================================================================
--- forms.py    (revision 4637)
+++ forms.py    (working copy)
@@ -227,9 +227,9 @@
         value = self.as_widget(self.field.widget)
         if not isinstance(value, basestring):
             # Some Widget render() methods -- notably RadioSelect -- return a
             # "special" object rather than a string. Call the __str__() on that
             # object to get its rendered value.
-            value = value.__str__()
+            value = value.__unicode__()
         return value

     def _errors(self):
@@ -227,9 +227,9 @@
         if not isinstance(value, basestring):
             # Some Widget render() methods -- notably RadioSelect -- return a
-            # "special" object rather than a string. Call the __str__() on that
+            # "special" object rather than a string. Call the __unicode__() on that
             # object to get its rendered value.
